==> modern_greek_inflexion-0.6.1-py3-none-any.whl: modern_greek_inflexion/resources/variables.py <==
# numb
SG = 'sg'
PL = 'pl'

# cases
NOM = 'nom'
GEN = 'gen'
ACC = 'acc'
VOC = 'voc'


# genders
MASC = 'masc'
FEM = 'fem'
NEUT = 'neut'
MASC_FEM = 'masc,fem'

SURNAME = 'surname'

ND = 'nd'
PRI = 'pri'
SEC = 'sec'
TER = 'ter'

# voice

ACTIVE = 'active'
PASSIVE = 'passive'
DEPONENS = 'deponens'
# tenses

AORIST = 'aorist'
PRESENT = 'present'
PARATATIKOS = 'paratatikos'
FIN = 'fin'
PAST = 'past'
# mood

IMP = 'imp'
CONJUNCTIVE = 'conjunctive'
IND = 'ind'
MODAL = 'modal'

# accents
ULTIMATE = 'ultimate'
PENULTIMATE = 'penultimate'
ANTEPENULTIMATE = 'antepenultimate'
INCORRECT_ACCENT = 'incorrect_accent'

# var
GENDER = 'gender'
CONJUGATION_IND = 'conjugation_ind'
CONJUGATION_IMP = 'conjugation_imp'
ROOT = 'root'
IMPER = 'imper'

# POS
ADJ = 'adj'
COMP = 'comp'
COMP_ADV = 'comp_adv'
ADVERB = 'adverb'
ADV = 'adv'
SUPERL = 'superl'
SUPERL_ADV = 'superl_adv'
COMPARATIVE = 'comparative'
ADVERB_COMPARATIVE = 'adverb_comparative'
# aspect

PERF = 'perf'
IMPERF = 'imperf'

# genders
NOM_PL = 'nom_pl'
GEN_SG = 'gen_sg'
NOM_SG = 'nom_sg'
FEM_PL = 'fem_pl'
MASC_PL = 'masc_pl'
NEUT_PL = 'neut_pl'
FEM_SG = 'fem_sg'
MASC_SG = 'masc_sg'
NEUT_SG = 'neut_sg'
ONLY_SG = 'only_sg'


# conjugations
EIMAI = 'eimai'
EIMAI_PARATATIKOS = "eimai_paratatikos"
PRESENT_ACTIVE_PART_EIMAI = "present_active_part_eimai"
IMPER_ACT_EIMAI = 'imper_act_eimai'
CON2AB = 'con2ab'
CON1_ACT = "con1_act"
CON2A_ACT = 'con2a_act'
CON2B_ACT = 'con2b_act'
CON2C_ACT = 'con2c_act'
CON2D_ACT = 'con2d_act'
CON1_ACT_MODAL = 'con1_act_modal'
CON2_ACT_MODAL = 'con2_act_modal'
PARAT2_ACT = 'parat2_act'
CON1_PASS = 'con1_pass'
CON2A_PASS = 'con2a_pass'
CON2AB_PASS = 'con2ab_pass'
CON2B_PASS = 'con2b_pass'
CON2C_PASS = 'con2c_pass'
CON2SA_PASS = 'con2sa_pass'
CON2D_PASS = 'con2d_pass'
CON2E_PASS = 'con2e_pass'
AOR_ACT = 'aor_act'
ARCH_PASS_AOR = 'arch_pass_aor'
ARCH_SEC_AOR = 'arch_sec_aor'
PARAT_ACT_MODAL = 'parat_act_modal'
PARAT1_PASS = 'parat1_pass'
IMPER_ACT_CONT_1 = 'imper_act_cont_1'
IMPER_ACT_CONT_2A = 'imper_act_cont_2a'
IMPER_ACT_CONT_2B = 'imper_act_cont_2b'
IMPER_ACT_CONT_2D = 'imper_act_cont_2d'
IMPER_ACT_CONT_2C = 'imper_act_cont_2c'
IMPER_PASS_CONT_2D = 'imper_pass_cont_2d'
IMPER_PASS_CONT_2E = 'imper_pass_cont_2e'
IMPER_PASS_CONT_1 = 'imper_pass_cont_1'
IMPER_PASS_CONT_2A = 'imper_pass_cont_2a'
IMPER_PASS_CONT_2B = 'imper_pass_cont_2b'
IMPER_PASS_CONT_2C = 'imper_pass_cont_2c'
PARAT2A_PASS = 'parat2a_pass'
PARAT2B_PASS = 'parat2b_pass'
PARAT2B_PASS_LOGIA = 'parat2b_pass_logia'
PARAT2C_PASS = 'parat2c_pass'
PARAT2D_PASS = 'parat2d_pass'
PARAT2E_PASS = 'parat2e_pass'
IMPER_ACT_AOR_A = 'imper_act_aor_a'
IMPER_ACT_AOR_B = 'imper_act_aor_b'
IMPER_ACT_AOR_C = 'imper_act_aor_c'
IMPER_ACT_AOR_D = 'imper_act_aor_d'
IMPER_ACT_AOR_CA = 'imper_act_aor_ca'
IMPER_PASS_AOR_A = 'imper_pass_aor_a'
IMPER_PASS_AOR_B = 'imper_pass_aor_b'
IMPER_PASS_CONT_2SA = 'imper_pass_cont_2sa'
PRESENT_ACTIVE_PART_1 = 'present_active_part_1'
PRESENT_ACTIVE_PART_2C = 'present_active_part_2c'
PRESENT_ACTIVE_PART_2 = 'present_active_part_2'
PRESENT_PASSIVE_PART_1 = 'present_passive_part_1'
PRESENT_PASSIVE_PART_2A = 'present_passive_part_2a'
PRESENT_PASSIVE_PART_2AB = 'present_passive_part_2ab'
PRESENT_PASSIVE_PART_2B = 'present_passive_part_2b'
PRESENT_PASSIVE_PART_2D = 'present_passive_part_2d'
PRESENT_PASSIVE_PART_2E = 'present_passive_part_2e'
PAST_PASSIVE_PART = 'past_passive_part'
CON1_PASS_MODAL = 'con1_pass_modal'
CON2_PASS_MODAL = 'con2_pass_modal'
PARAT2B_LOGIA = 'parat2b_logia'

==> modern_greek_inflexion-0.6.8-py3-none-any.whl: modern_greek_inflexion/resources/variables.py <==
# numb
SG = 'sg'
PL = 'pl'

# cases
NOM = 'nom'
GEN = 'gen'
ACC = 'acc'
VOC = 'voc'

# genders
MASC = 'masc'
FEM = 'fem'
NEUT = 'neut'
MASC_FEM = 'masc,fem'

SURNAME = 'surname'

ND = 'nd'
PRI = 'pri'
SEC = 'sec'
TER = 'ter'

# voice

ACTIVE = 'active'
PASSIVE = 'passive'
DEPONENS = 'deponens'
# tenses

AORIST = 'aorist'
PRESENT = 'present'
PARATATIKOS = 'paratatikos'
FIN = 'fin'
PAST = 'past'
# mood

IMP = 'imp'
CONJUNCTIVE = 'conjunctive'
IND = 'ind'
MODAL = 'modal'

# accents
ULTIMATE = 'ultimate'
PENULTIMATE = 'penultimate'
ANTEPENULTIMATE = 'antepenultimate'
INCORRECT_ACCENT = 'incorrect_accent'

# var
GENDER = 'gender'
CONJUGATION_IND = 'conjugation_ind'
CONJUGATION_IMP = 'conjugation_imp'
ROOT = 'root'
IMPER = 'imper'

# POS
ADJ = 'adj'
COMP = 'comp'
COMP_ADV = 'comp_adv'
ADVERB = 'adverb'
ADV = 'adv'
SUPERL = 'superl'
SUPERL_ADV = 'superl_adv'
COMPARATIVE = 'comparative'
ADVERB_COMPARATIVE = 'adverb_comparative'
# aspect

PERF = 'perf'
IMPERF = 'imperf'

# genders
NOM_PL = 'nom_pl'
GEN_SG = 'gen_sg'
NOM_SG = 'nom_sg'
FEM_PL = 'fem_pl'
MASC_PL = 'masc_pl'
NEUT_PL = 'neut_pl'
FEM_SG = 'fem_sg'
MASC_SG = 'masc_sg'
NEUT_SG = 'neut_sg'
ONLY_SG = 'only_sg'

# conjugations
EIMAI = 'eimai'
EIMAI_PARATATIKOS = "eimai_paratatikos"
PRESENT_ACTIVE_PART_EIMAI = "present_active_part_eimai"
IMPER_ACT_EIMAI = 'imper_act_eimai'
CON2AB = 'con2ab'
CON1_ACT = "con1_act"
CON2A_ACT = 'con2a_act'
CON2B_ACT = 'con2b_act'
CON2C_ACT = 'con2c_act'
CON2D_ACT = 'con2d_act'
CON1_ACT_MODAL = 'con1_act_modal'
CON2_ACT_MODAL = 'con2_act_modal'
PARAT2_ACT = 'parat2_act'
CON1_PASS = 'con1_pass'
CON2A_PASS = 'con2a_pass'
CON2AB_PASS = 'con2ab_pass'
CON2B_PASS = 'con2b_pass'
CON2C_PASS = 'con2c_pass'
CON2SA_PASS = 'con2sa_pass'
CON2D_PASS = 'con2d_pass'
CON2E_PASS = 'con2e_pass'
AOR_ACT = 'aor_act'
ARCH_PASS_AOR = 'arch_pass_aor'
ARCH_SEC_AOR = 'arch_sec_aor'
PARAT_ACT_MODAL = 'parat_act_modal'
PARAT1_PASS = 'parat1_pass'
IMPER_ACT_CONT_1 = 'imper_act_cont_1'
IMPER_ACT_CONT_2A = 'imper_act_cont_2a'
IMPER_ACT_CONT_2B = 'imper_act_cont_2b'
IMPER_ACT_CONT_2D = 'imper_act_cont_2d'
IMPER_ACT_CONT_2C = 'imper_act_cont_2c'
IMPER_PASS_CONT_2D = 'imper_pass_cont_2d'
IMPER_PASS_CONT_2E = 'imper_pass_cont_2e'
IMPER_PASS_CONT_1 = 'imper_pass_cont_1'
IMPER_PASS_CONT_2A = 'imper_pass_cont_2a'
IMPER_PASS_CONT_2B = 'imper_pass_cont_2b'
IMPER_PASS_CONT_2C = 'imper_pass_cont_2c'
PARAT2A_PASS = 'parat2a_pass'
PARAT2B_PASS = 'parat2b_pass'
PARAT2B_PASS_LOGIA = 'parat2b_pass_logia'
PARAT2C_PASS = 'parat2c_pass'
PARAT2D_PASS = 'parat2d_pass'
PARAT2E_PASS = 'parat2e_pass'
IMPER_ACT_AOR_A = 'imper_act_aor_a'
IMPER_ACT_AOR_B = 'imper_act_aor_b'
IMPER_ACT_AOR_C = 'imper_act_aor_c'
IMPER_ACT_AOR_D = 'imper_act_aor_d'
IMPER_ACT_AOR_CA = 'imper_act_aor_ca'
IMPER_PASS_AOR_A = 'imper_pass_aor_a'
IMPER_PASS_AOR_B = 'imper_pass_aor_b'
IMPER_PASS_CONT_2SA = 'imper_pass_cont_2sa'
PRESENT_ACTIVE_PART_1 = 'present_active_part_1'
PRESENT_ACTIVE_PART_2C = 'present_active_part_2c'
PRESENT_ACTIVE_PART_2 = 'present_active_part_2'
PRESENT_PASSIVE_PART_1 = 'present_passive_part_1'
PRESENT_PASSIVE_PART_2A = 'present_passive_part_2a'
PRESENT_PASSIVE_PART_2AB = 'present_passive_part_2ab'
PRESENT_PASSIVE_PART_2B = 'present_passive_part_2b'
PRESENT_PASSIVE_PART_2D = 'present_passive_part_2d'
PRESENT_PASSIVE_PART_2E = 'present_passive_part_2e'
PAST_PASSIVE_PART = 'past_passive_part'
CON1_PASS_MODAL = 'con1_pass_modal'
CON2_PASS_MODAL = 'con2_pass_modal'
PARAT2B_LOGIA = 'parat2b_logia'

WITHOUT_GEN_PL = 'without_gen_pl'
PROPAROKSITONA_GEN_PL = 'proparoksitona_gen_pl'
PAROKSITONA_GEN_PL = 'paroksitona_gen_pl'
PAROKSITONA_GEN_PL_MOVING = 'paroksitona_gen_pl_moving'
OKSITONA_GEN_PL_MASC = 'oksitona_gen_pl_masc'
VOCATIVE_MASC_SG_O = 'vocative_masc_sg_o'
FEMININA_H_EIS = 'feminina_h_eis'
FEMININA_OS = 'feminina_os'
PAROKSITONA_GEN_NEUT_I = 'paroksitona_gen_neut_i'
WITHOUT_GEN_NEUT_I = 'without_gen_neut_i'
